/* countdown - count down a specified time interval
**
** Copyright  2012,2014 by Jef Poskanzer <jef@mail.acme.com>.
** All rights reserved.
**
** Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions
** are met:
** 1. Redistributions of source code must retain the above copyright
**    notice, this list of conditions and the following disclaimer.
** 2. Redistributions in binary form must reproduce the above copyright
**    notice, this list of conditions and the following disclaimer in the
**    documentation and/or other materials provided with the distribution.
**
** THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
** ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
** IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
** ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
** FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
** DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
** OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
** HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
** LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
** OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
** SUCH DAMAGE.
**
** For commentary on this license please see http://acme.com/license.html
*/

#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>

#define MINUTE 60
#define HOUR (60*MINUTE)
#define DAY (24*HOUR)
#define WEEK (7*DAY)

int
main( int argc, char** argv )
    {
    char* interval_s;
    int interval_n;
    char interval_c;
    int seconds, i;

    if ( argc != 2 )
	{
	(void) fprintf( stderr, "usage:  %s interval\n", argv[0] );
	exit( EXIT_FAILURE );
	}
    interval_s = argv[1];

    interval_n = atoi( interval_s );
    interval_c = interval_s[ strlen( interval_s ) - 1];
    switch ( interval_c )
	{
	case 's': case 'S':
	case '0': case '1': case '2': case '3': case '4':
	case '5': case '6': case '7': case '8': case '9':
	seconds = interval_n;
	break;
	case 'm': case 'M':
	seconds = interval_n * MINUTE;
	break;
	case 'h': case 'H':
	seconds = interval_n * HOUR;
	break;
	case 'd': case 'D':
	seconds = interval_n * DAY;
	break;
	case 'w': case 'W':
	seconds = interval_n * WEEK;
	break;
	default:
	(void) fprintf( stderr, "%s: unknown interval char - '%c'\n", argv[0], interval_c );
	exit( EXIT_FAILURE );
	}

    for (;;)
	{
	if ( seconds >= DAY )
	    {
	    (void) printf( "\r%dd %dh %dm %ds   ", seconds / DAY, ( seconds % DAY ) / HOUR, ( seconds % HOUR ) / MINUTE, seconds % MINUTE );
	    }
	else if ( seconds >= HOUR )
	    (void) printf( "\r%dh %dm %ds   ", seconds / HOUR, ( seconds % HOUR ) / MINUTE, seconds % MINUTE );
	else if ( seconds >= MINUTE )
	    (void) printf( "\r%dm %ds   ", seconds / MINUTE, seconds % MINUTE );
	else
	    (void) printf( "\r%ds   ", seconds );
	(void) fflush( stdout );
	if ( seconds == 0 )
	    break;
	sleep( 1 );
	--seconds;
	}

    (void) printf( "\n" );
    for ( i = 0; i < 5; ++i )
	{
	(void) putchar( '' );
	(void) fflush( stdout );
	sleep( 1 );
	}

    exit( EXIT_SUCCESS );
    }
